﻿--[[
Name: LibBabble-Boss-3.0
Revision: $Rev: 157 $
Author(s): ckknight (ckknight@gmail.com)
Website: http://ckknight.wowinterface.com/
Description: A library to provide localizations for bosses.
Dependencies: None
License: MIT
]]

local MAJOR_VERSION = "LibBabble-Boss-3.0"
local MINOR_VERSION = 90000 + tonumber(("$Revision: 157 $"):match("%d+"))

-- #AUTODOC_NAMESPACE prototype

local GAME_LOCALE = GetLocale()
do
	-- LibBabble-Core-3.0 is hereby placed in the Public Domain
	-- Credits: ckknight
	local LIBBABBLE_MAJOR, LIBBABBLE_MINOR = "LibBabble-3.0", 2

	local LibBabble = LibStub:NewLibrary(LIBBABBLE_MAJOR, LIBBABBLE_MINOR)
	if LibBabble then
		local data = LibBabble.data or {}
		for k,v in pairs(LibBabble) do
			LibBabble[k] = nil
		end
		LibBabble.data = data

		local tablesToDB = {}
		for namespace, db in pairs(data) do
			for k,v in pairs(db) do
				tablesToDB[v] = db
			end
		end
		
		local function warn(message)
			local _, ret = pcall(error, message, 3)
			geterrorhandler()(ret)
		end

		local lookup_mt = { __index = function(self, key)
			local db = tablesToDB[self]
			local current_key = db.current[key]
			if current_key then
				self[key] = current_key
				return current_key
			end
			local base_key = db.base[key]
			local real_MAJOR_VERSION
			for k,v in pairs(data) do
				if v == db then
					real_MAJOR_VERSION = k
					break
				end
			end
			if not real_MAJOR_VERSION then
				real_MAJOR_VERSION = LIBBABBLE_MAJOR
			end
			if base_key then
				warn(("%s: Translation %q not found for locale %q"):format(real_MAJOR_VERSION, key, GAME_LOCALE))
				rawset(self, key, base_key)
				return base_key
			end
			warn(("%s: Translation %q not found."):format(real_MAJOR_VERSION, key))
			rawset(self, key, key)
			return key
		end }

		local function initLookup(module, lookup)
			local db = tablesToDB[module]
			for k in pairs(lookup) do
				lookup[k] = nil
			end
			setmetatable(lookup, lookup_mt)
			tablesToDB[lookup] = db
			db.lookup = lookup
			return lookup
		end

		local function initReverse(module, reverse)
			local db = tablesToDB[module]
			for k in pairs(reverse) do
				reverse[k] = nil
			end
			for k,v in pairs(db.current) do
				reverse[v] = k
			end
			tablesToDB[reverse] = db
			db.reverse = reverse
			db.reverseIterators = nil
			return reverse
		end

		local prototype = {}
		local prototype_mt = {__index = prototype}

		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will warn but allow the code to pass through.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local BL = B:GetLookupTable()
			assert(BL["Some english word"] == "Some localized word")
			DoSomething(BL["Some english word that doesn't exist"]) -- warning!
		-----------------------------------------------------------------------------]]
		function prototype:GetLookupTable()
			local db = tablesToDB[self]

			local lookup = db.lookup
			if lookup then
				return lookup
			end
			return initLookup(self, {})
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local B_has = B:GetUnstrictLookupTable()
			assert(B_has["Some english word"] == "Some localized word")
			assert(B_has["Some english word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetUnstrictLookupTable()
			local db = tablesToDB[self]

			return db.current
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
			* This is useful for checking if the base (English) table has a key, even if the localized one does not have it registered.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local B_hasBase = B:GetBaseLookupTable()
			assert(B_hasBase["Some english word"] == "Some english word")
			assert(B_hasBase["Some english word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetBaseLookupTable()
			local db = tablesToDB[self]

			return db.base
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
			* This will return only one English word that it maps to, if there are more than one to check, see :GetReverseIterator("word")
		Returns:
			A lookup table for localized to english words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local BR = B:GetReverseLookupTable()
			assert(BR["Some localized word"] == "Some english word")
			assert(BR["Some localized word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetReverseLookupTable()
			local db = tablesToDB[self]

			local reverse = db.reverse
			if reverse then
				return reverse
			end
			return initReverse(self, {})
		end
		local blank = {}
		local weakVal = {__mode='v'}
		--[[---------------------------------------------------------------------------
		Arguments:
			string - the localized word to chek for.
		Returns:
			An iterator to traverse all English words that map to the given key
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			for word in B:GetReverseIterator("Some localized word") do
				DoSomething(word)
			end
		-----------------------------------------------------------------------------]]
		function prototype:GetReverseIterator(key)
			local db = tablesToDB[self]
			local reverseIterators = db.reverseIterators
			if not reverseIterators then
				reverseIterators = setmetatable({}, weakVal)
				db.reverseIterators = reverseIterators
			elseif reverseIterators[key] then
				return pairs(reverseIterators[key])
			end
			local t
			for k,v in pairs(db.current) do
				if v == key then
					if not t then
						t = {}
					end
					t[k] = true
				end
			end
			reverseIterators[key] = t or blank
			return pairs(reverseIterators[key])
		end
		--[[---------------------------------------------------------------------------
		Returns:
			An iterator to traverse all translations English to localized.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			for english, localized in B:Iterate() do
				DoSomething(english, localized)
			end
		-----------------------------------------------------------------------------]]
		function prototype:Iterate()
			local db = tablesToDB[self]

			return pairs(db.current)
		end

		-- #NODOC
		-- modules need to call this to set the base table
		function prototype:SetBaseTranslations(base)
			local db = tablesToDB[self]
			local oldBase = db.base
			if oldBase then
				for k in pairs(oldBase) do
					oldBase[k] = nil
				end
				for k, v in pairs(base) do
					oldBase[k] = v
				end
				base = oldBase
			else
				db.base = base
			end
			for k,v in pairs(base) do
				if v == true then
					base[k] = k
				end
			end
		end

		local function init(module)
			local db = tablesToDB[module]
			if db.lookup then
				initLookup(module, db.lookup)
			end
			if db.reverse then
				initReverse(module, db.reverse)
			end
			db.reverseIterators = nil
		end

		-- #NODOC
		-- modules need to call this to set the current table. if current is true, use the base table.
		function prototype:SetCurrentTranslations(current)
			local db = tablesToDB[self]
			if current == true then
				db.current = db.base
			else
				local oldCurrent = db.current
				if oldCurrent then
					for k in pairs(oldCurrent) do
						oldCurrent[k] = nil
					end
					for k, v in pairs(current) do
						oldCurrent[k] = v
					end
					current = oldCurrent
				else
					db.current = current
				end
			end
			init(self)
		end

		for namespace, db in pairs(data) do
			setmetatable(db.module, prototype_mt)
			init(db.module)
		end

		-- #NODOC
		-- modules need to call this to create a new namespace.
		function LibBabble:New(namespace, minor)
			local module, oldminor = LibStub:NewLibrary(namespace, minor)
			if not module then
				return
			end

			if not oldminor then
				local db = {
					module = module,
				}
				data[namespace] = db
				tablesToDB[module] = db
			else
				for k,v in pairs(module) do
					module[k] = nil
				end
			end

			setmetatable(module, prototype_mt)

			return module
		end
	end
end

local lib = LibStub("LibBabble-3.0"):New(MAJOR_VERSION, MINOR_VERSION)
if not lib then
	return
end

lib:SetBaseTranslations
--[===[@debug@
{
--@end-debug@]===]
{
	Aeonus = "Aeonus",
	["Agathelos the Raging"] = "Agathelos the Raging",
	Ahune = "Ahune",
	["Akil'zon"] = "Akil'zon",
	["Aku'mai"] = "Aku'mai",
	["Al'ar"] = "Al'ar",
	["Alzzin the Wildshaper"] = "Alzzin the Wildshaper",
	Amanitar = "Amanitar",
	["Ambassador Flamelash"] = "Ambassador Flamelash",
	["Ambassador Hellmaw"] = "Ambassador Hellmaw",
	["Amnennar the Coldbringer"] = "Amnennar the Coldbringer",
	["Ancient Stone Keeper"] = "Ancient Stone Keeper",
	Anetheron = "Anetheron",
	["Anger'rel"] = "Anger'rel",
	Anomalus = "Anomalus",
	["Antu'sul"] = "Antu'sul",
	["Anub'arak"] = "Anub'arak",
	["Anub'Rekhan"] = "Anub'Rekhan",
	["Anub'shiah"] = "Anub'shiah",
	["Anubisath Defender"] = "Anubisath Defender",
	["Anubisath Guardian"] = "Anubisath Guardian",
	Anzu = "Anzu",
	["Arcane Watchman"] = "Arcane Watchman",
	["Arcanist Doan"] = "Arcanist Doan",
	Archaedas = "Archaedas",
	["Archavon the Stone Watcher"] = "Archavon the Stone Watcher",
	Archimonde = "Archimonde",
	["Archivist Galford"] = "Archivist Galford",
	["Archmage Arugal"] = "Archmage Arugal",
	["Arugal's Voidwalker"] = "Arugal's Voidwalker",
	["Atal'alarion"] = "Atal'alarion",
	["Attumen the Huntsman"] = "Attumen the Huntsman",
	Avalanchion = "Avalanchion",
	["Avatar of Hakkar"] = "Avatar of Hakkar",
	["Ayamiss the Hunter"] = "Ayamiss the Hunter",
	Azgalor = "Azgalor",
	["Azshir the Sleepless"] = "Azshir the Sleepless",
	Azuregos = "Azuregos",
	["Bael'Gar"] = "Bael'Gar",
	Baelog = "Baelog",
	Balnazzar = "Balnazzar",
	["Bannok Grimaxe"] = "Bannok Grimaxe",
	["Baron Aquanis"] = "Baron Aquanis",
	["Baron Charr"] = "Baron Charr",
	["Baron Geddon"] = "Baron Geddon",
	["Baron Kazum"] = "Baron Kazum",
	["Baron Rivendare"] = "Baron Rivendare",
	["Baron Silverlaine"] = "Baron Silverlaine",
	["Baroness Anastari"] = "Baroness Anastari",
	["Battleguard Sartura"] = "Battleguard Sartura",
	["Bazil Thredd"] = "Bazil Thredd",
	Bazzalan = "Bazzalan",
	["Black Guard Swordsmith"] = "Black Guard Swordsmith",
	["Blackheart the Inciter"] = "Blackheart the Inciter",
	["Blind Hunter"] = "Blind Hunter",
	["Blindeye the Seer"] = "Blindeye the Seer",
	["Blood Guard Porung"] = "Blood Guard Porung",
	["Blood Steward of Kirtonos"] = "Blood Steward of Kirtonos",
	["Bloodlord Mandokir"] = "Bloodlord Mandokir",
	["Bloodmage Thalnos"] = "Bloodmage Thalnos",
	Boahn = "Boahn",
	["Brainwashed Noble"] = "Brainwashed Noble",
	Broggok = "Broggok",
	Brokentoe = "Brokentoe",
	["Broodlord Lashlayer"] = "Broodlord Lashlayer",
	["Bruegal Ironknuckle"] = "Bruegal Ironknuckle",
	Brutallus = "Brutallus",
	["Burning Felguard"] = "Burning Felguard",
	["Buru the Gorger"] = "Buru the Gorger",
	["C'Thun"] = "C'Thun",
	["Cache of the Firelord"] = "Cache of the Firelord",
	["Cannon Master Willey"] = "Cannon Master Willey",
	["Captain Greenskin"] = "Captain Greenskin",
	["Captain Kromcrush"] = "Captain Kromcrush",
	["Captain Skarloc"] = "Captain Skarloc",
	["Celebras the Cursed"] = "Celebras the Cursed",
	["Charlga Razorflank"] = "Charlga Razorflank",
	["Chess Event"] = "Chess Event",
	["Chest of The Seven"] = "Chest of The Seven",
	["Chief Ukorz Sandscalp"] = "Chief Ukorz Sandscalp",
	["Cho'Rush the Observer"] = "Cho'Rush the Observer",
	Chromaggus = "Chromaggus",
	["Chrono Lord Deja"] = "Chrono Lord Deja",
	["Chrono-Lord Epoch"] = "Chrono-Lord Epoch",
	Claw = "Claw",
	["Coilfang Elite"] = "Coilfang Elite",
	["Coilfang Strider"] = "Coilfang Strider",
	["Commander Kolurg"] = "Commander Kolurg",
	["Commander Sarannis"] = "Commander Sarannis",
	["Commander Springvale"] = "Commander Springvale",
	["Commander Stoutbeard"] = "Commander Stoutbeard",
	["Constructor & Controller"] = "Constructor & Controller",
	Cookie = "Cookie",
	["Cosmic Infuser"] = "Cosmic Infuser",
	["Crimson Hammersmith"] = "Crimson Hammersmith",
	["Crowd Pummeler 9-60"] = "Crowd Pummeler 9-60",
	["Crystal Fang"] = "Crystal Fang",
	Cyanigosa = "Cyanigosa",
	["Dalliah the Doomsayer"] = "Dalliah the Doomsayer",
	["Dalronn the Controller"] = "Dalronn the Controller",
	["Dark Iron Ambassador"] = "Dark Iron Ambassador",
	["Darkmaster Gandling"] = "Darkmaster Gandling",
	["Darkweaver Syth"] = "Darkweaver Syth",
	["Death Knight Darkreaver"] = "Death Knight Darkreaver",
	["Death knight Understudy"] = "Death knight Understudy",
	["Death Speaker Jargba"] = "Death Speaker Jargba",
	["Deathsworn Captain"] = "Deathsworn Captain",
	Devastation = "Devastation",
	["Deviate Faerie Dragon"] = "Deviate Faerie Dragon",
	["Dextren Ward"] = "Dextren Ward",
	["Digmaster Shovelphlange"] = "Digmaster Shovelphlange",
	["Doctor Theolen Krastinov"] = "Doctor Theolen Krastinov",
	["Doom Lord Kazzak"] = "Doom Lord Kazzak",
	["Doom'rel"] = "Doom'rel",
	Doomwalker = "Doomwalker",
	["Dope'rel"] = "Dope'rel",
	Dorothee = "Dorothee",
	["Drakkari Colossus"] = "Drakkari Colossus",
	["Drakos the Interrogator"] = "Drakos the Interrogator",
	Dreamscythe = "Dreamscythe",
	["Dust Covered Chest"] = "Dust Covered Chest",
	Dustwraith = "Dustwraith",
	["Earthcaller Halmgar"] = "Earthcaller Halmgar",
	Ebonroc = "Ebonroc",
	["Eck the Ferocious"] = "Eck the Ferocious",
	["Edwin VanCleef"] = "Edwin VanCleef",
	["Elder Nadox"] = "Elder Nadox",
	["Electrocutioner 6000"] = "Electrocutioner 6000",
	Emeriss = "Emeriss",
	["Emperor Dagran Thaurissan"] = "Emperor Dagran Thaurissan",
	["Emperor Vek'lor"] = "Emperor Vek'lor",
	["Emperor Vek'nilash"] = "Emperor Vek'nilash",
	Entropius = "Entropius",
	["Epoch Hunter"] = "Epoch Hunter",
	Erekem = "Erekem",
	["Essence of Anger"] = "Essence of Anger",
	["Essence of Desire"] = "Essence of Desire",
	["Essence of Suffering"] = "Essence of Suffering",
	Eviscerator = "Eviscerator",
	["Exarch Maladaar"] = "Exarch Maladaar",
	["Eye of C'Thun"] = "Eye of C'Thun",
	["Fallen Champion"] = "Fallen Champion",
	["Fankriss the Unyielding"] = "Fankriss the Unyielding",
	["Fathom-Lord Karathress"] = "Fathom-Lord Karathress",
	Felmyst = "Felmyst",
	["Fenrus the Devourer"] = "Fenrus the Devourer",
	Feugen = "Feugen",
	["Fineous Darkvire"] = "Fineous Darkvire",
	Firemaw = "Firemaw",
	Flamegor = "Flamegor",
	["Foreman Thistlenettle"] = "Foreman Thistlenettle",
	["Four Horsemen Chest"] = "Four Horsemen Chest",
	["Fras Siabi"] = "Fras Siabi",
	["Gahz'ranka"] = "Gahz'ranka",
	["Gahz'rilla"] = "Gahz'rilla",
	["Gal'darah"] = "Gal'darah",
	["Galgann Firehammer"] = "Galgann Firehammer",
	Garr = "Garr",
	Gasher = "Gasher",
	["Gatewatcher Gyro-Kill"] = "Gatewatcher Gyro-Kill",
	["Gatewatcher Iron-Hand"] = "Gatewatcher Iron-Hand",
	["Gathios the Shatterer"] = "Gathios the Shatterer",
	Gehennas = "Gehennas",
	Gelihast = "Gelihast",
	Gelk = "Gelk",
	["General Angerforge"] = "General Angerforge",
	["General Bjarngrim"] = "General Bjarngrim",
	["General Drakkisath"] = "General Drakkisath",
	["General Rajaxx"] = "General Rajaxx",
	["Ghamoo-ra"] = "Ghamoo-ra",
	["Ghaz'an"] = "Ghaz'an",
	["Ghok Bashguud"] = "Ghok Bashguud",
	Gilnid = "Gilnid",
	["Gizrul the Slavener"] = "Gizrul the Slavener",
	["Gloom'rel"] = "Gloom'rel",
	Gluth = "Gluth",
	Glutton = "Glutton",
	["Golem Lord Argelmach"] = "Golem Lord Argelmach",
	["Golemagg the Incinerator"] = "Golemagg the Incinerator",
	["Goraluk Anvilcrack"] = "Goraluk Anvilcrack",
	["Gorosh the Dervish"] = "Gorosh the Dervish",
	["Gortok Palehoof"] = "Gortok Palehoof",
	["Gothik the Harvester"] = "Gothik the Harvester",
	["Grand Astromancer Capernian"] = "Grand Astromancer Capernian",
	["Grand Magus Telestra"] = "Grand Magus Telestra",
	["Grand Warlock Alythess"] = "Grand Warlock Alythess",
	["Grand Warlock Nethekurse"] = "Grand Warlock Nethekurse",
	["Grand Widow Faerlina"] = "Grand Widow Faerlina",
	["Grandmaster Vorpil"] = "Grandmaster Vorpil",
	Grandmother = "Grandmother",
	["Grethok the Controller"] = "Grethok the Controller",
	["Gri'lek"] = "Gri'lek",
	Grimlok = "Grimlok",
	Grizzle = "Grizzle",
	Grobbulus = "Grobbulus",
	Grubbis = "Grubbis",
	["Gruul the Dragonkiller"] = "Gruul the Dragonkiller",
	["Guard Fengus"] = "Guard Fengus",
	["Guard Mol'dar"] = "Guard Mol'dar",
	["Guard Slip'kik"] = "Guard Slip'kik",
	["Gurtogg Bloodboil"] = "Gurtogg Bloodboil",
	Gyth = "Gyth",
	Hadronox = "Hadronox",
	Hakkar = "Hakkar",
	Halazzi = "Halazzi",
	Halycon = "Halycon",
	Hamhock = "Hamhock",
	["Harbinger Skyriss"] = "Harbinger Skyriss",
	["Hate'rel"] = "Hate'rel",
	["Hazza'rah"] = "Hazza'rah",
	Hazzas = "Hazzas",
	["Headless Horseman"] = "Headless Horseman",
	["Hearthsinger Forresten"] = "Hearthsinger Forresten",
	["Hedrum the Creeper"] = "Hedrum the Creeper",
	["Heigan the Unclean"] = "Heigan the Unclean",
	["Hellfire Channeler"] = "Hellfire Channeler",
	["Henry Stern"] = "Henry Stern",
	["Herald Volazj"] = "Herald Volazj",
	Herod = "Herod",
	["Hex Lord Malacrass"] = "Hex Lord Malacrass",
	["High Astromancer Solarian"] = "High Astromancer Solarian",
	["High Botanist Freywinn"] = "High Botanist Freywinn",
	["High Inquisitor Fairbanks"] = "High Inquisitor Fairbanks",
	["High Inquisitor Whitemane"] = "High Inquisitor Whitemane",
	["High Interrogator Gerstahn"] = "High Interrogator Gerstahn",
	["High King Maulgar"] = "High King Maulgar",
	["High Marshal Whirlaxis"] = "High Marshal Whirlaxis",
	["High Nethermancer Zerevor"] = "High Nethermancer Zerevor",
	["High Priest Thekal"] = "High Priest Thekal",
	["High Priest Venoxis"] = "High Priest Venoxis",
	["High Priestess Arlokk"] = "High Priestess Arlokk",
	["High Priestess Jeklik"] = "High Priestess Jeklik",
	["High Priestess Mar'li"] = "High Priestess Mar'li",
	["High Priestess of Thaurissan"] = "High Priestess of Thaurissan",
	["High Warlord Naj'entus"] = "High Warlord Naj'entus",
	["Highlord Mograine"] = "Highlord Mograine",
	["Highlord Omokk"] = "Highlord Omokk",
	["Houndmaster Grebmar"] = "Houndmaster Grebmar",
	["Houndmaster Loksey"] = "Houndmaster Loksey",
	Hukku = "Hukku",
	Hungarfen = "Hungarfen",
	["Hurley Blackbreath"] = "Hurley Blackbreath",
	["Hyakiss the Lurker"] = "Hyakiss the Lurker",
	["Hydromancer Thespia"] = "Hydromancer Thespia",
	["Hydromancer Velratha"] = "Hydromancer Velratha",
	Hydrospawn = "Hydrospawn",
	["Hydross the Unstable"] = "Hydross the Unstable",
	Ichoron = "Ichoron",
	["Illidan Stormrage"] = "Illidan Stormrage",
	["Illidari Council"] = "Illidari Council",
	["Illyanna Ravenoak"] = "Illyanna Ravenoak",
	["Immol'thar"] = "Immol'thar",
	["Infinite Corruptor"] = "Infinite Corruptor",
	["Infinity Blades"] = "Infinity Blades",
	["Ingvar the Plunderer"] = "Ingvar the Plunderer",
	["Instructor Malicia"] = "Instructor Malicia",
	["Instructor Razuvious"] = "Instructor Razuvious",
	["Interrogator Vishas"] = "Interrogator Vishas",
	Ionar = "Ionar",
	Ironaya = "Ironaya",
	Ironspine = "Ironspine",
	Isalien = "Isalien",
	Jade = "Jade",
	["Jammal'an the Prophet"] = "Jammal'an the Prophet",
	["Jan'alai"] = "Jan'alai",
	["Jandice Barov"] = "Jandice Barov",
	["Jed Runewatcher"] = "Jed Runewatcher",
	["Jedoga Shadowseeker"] = "Jedoga Shadowseeker",
	["Jergosh the Invoker"] = "Jergosh the Invoker",
	["Jin'do the Hexxer"] = "Jin'do the Hexxer",
	Julianne = "Julianne",
	["Kael'thas Sunstrider"] = "Kael'thas Sunstrider",
	Kalecgos = "Kalecgos",
	["Kam Deepfury"] = "Kam Deepfury",
	["Kaz'rogal"] = "Kaz'rogal",
	["Kazkaz the Unholy"] = "Kazkaz the Unholy",
	["Kel'Thuzad"] = "Kel'Thuzad",
	["Keli'dan the Breaker"] = "Keli'dan the Breaker",
	Keristrasza = "Keristrasza",
	["Kiggler the Crazed"] = "Kiggler the Crazed",
	["Kil'jaeden"] = "Kil'jaeden",
	["Kil'rek"] = "Kil'rek",
	["King Dred"] = "King Dred",
	["King Gordok"] = "King Gordok",
	["King Llane Piece"] = "King Llane Piece",
	["King Ymiron"] = "King Ymiron",
	["Kirtonos the Herald"] = "Kirtonos the Herald",
	["Knot Thimblejack's Cache"] = "Knot Thimblejack's Cache",
	Kolk = "Kolk",
	Kormok = "Kormok",
	Kresh = "Kresh",
	["Krik'thir the Gatewatcher"] = "Krik'thir the Gatewatcher",
	["Krosh Firehand"] = "Krosh Firehand",
	Krystallus = "Krystallus",
	Kurinnaxx = "Kurinnaxx",
	["Lady Anacondra"] = "Lady Anacondra",
	["Lady Blaumeux"] = "Lady Blaumeux",
	["Lady Illucia Barov"] = "Lady Illucia Barov",
	["Lady Malande"] = "Lady Malande",
	["Lady Sacrolash"] = "Lady Sacrolash",
	["Lady Sarevess"] = "Lady Sarevess",
	["Lady Vashj"] = "Lady Vashj",
	Laj = "Laj",
	Landslide = "Landslide",
	Lavanthor = "Lavanthor",
	["Leotheras the Blind"] = "Leotheras the Blind",
	Lethon = "Lethon",
	Lethtendris = "Lethtendris",
	["Ley-Guardian Eregos"] = "Ley-Guardian Eregos",
	["Lieutenant Drake"] = "Lieutenant Drake",
	["Lieutenant General Andorov"] = "Lieutenant General Andorov",
	Loatheb = "Loatheb",
	Loken = "Loken",
	["Lord Alexei Barov"] = "Lord Alexei Barov",
	["Lord Cobrahn"] = "Lord Cobrahn",
	["Lord Hel'nurath"] = "Lord Hel'nurath",
	["Lord Incendius"] = "Lord Incendius",
	["Lord Kazzak"] = "Lord Kazzak",
	["Lord Kri"] = "Lord Kri",
	["Lord Pythas"] = "Lord Pythas",
	["Lord Roccor"] = "Lord Roccor",
	["Lord Sanguinar"] = "Lord Sanguinar",
	["Lord Serpentis"] = "Lord Serpentis",
	["Lord Skwol"] = "Lord Skwol",
	["Lord Valthalak"] = "Lord Valthalak",
	["Lord Victor Nefarius"] = "Lord Victor Nefarius",
	["Lord Vyletongue"] = "Lord Vyletongue",
	["Lorekeeper Polkelt"] = "Lorekeeper Polkelt",
	Loro = "Loro",
	Lucifron = "Lucifron",
	["M'uru"] = "M'uru",
	["Mad Magglish"] = "Mad Magglish",
	Maexxna = "Maexxna",
	["Mage-Lord Urom"] = "Mage-Lord Urom",
	["Magister Kalendris"] = "Magister Kalendris",
	["Magistrate Barthilas"] = "Magistrate Barthilas",
	Magmadar = "Magmadar",
	Magmus = "Magmus",
	Magra = "Magra",
	Magtheridon = "Magtheridon",
	["Maiden of Grief"] = "Maiden of Grief",
	["Maiden of Virtue"] = "Maiden of Virtue",
	["Majordomo Executus"] = "Majordomo Executus",
	["Mal'Ganis"] = "Mal'Ganis",
	Malacrass = "Malacrass",
	["Maleki the Pallid"] = "Maleki the Pallid",
	Malygos = "Malygos",
	Maraudos = "Maraudos",
	["Marduk Blackpool"] = "Marduk Blackpool",
	["Marisa du'Paige"] = "Marisa du'Paige",
	["Master Engineer Telonicus"] = "Master Engineer Telonicus",
	["Maur Grimtotem"] = "Maur Grimtotem",
	Meathook = "Meathook",
	["Mechano-Lord Capacitus"] = "Mechano-Lord Capacitus",
	Medivh = "Medivh",
	["Mekgineer Steamrigger"] = "Mekgineer Steamrigger",
	["Mekgineer Thermaplugg"] = "Mekgineer Thermaplugg",
	["Mennu the Betrayer"] = "Mennu the Betrayer",
	["Meshlok the Harvester"] = "Meshlok the Harvester",
	Midnight = "Midnight",
	Mijan = "Mijan",
	["Miner Johnson"] = "Miner Johnson",
	Moam = "Moam",
	Mogor = "Mogor",
	Moorabi = "Moorabi",
	["Mor Grayhoof"] = "Mor Grayhoof",
	Moragg = "Moragg",
	["Mordresh Fire Eye"] = "Mordresh Fire Eye",
	Moroes = "Moroes",
	["Morogrim Tidewalker"] = "Morogrim Tidewalker",
	Morphaz = "Morphaz",
	["Mother Shahraz"] = "Mother Shahraz",
	["Mother Smolderweb"] = "Mother Smolderweb",
	["Mr. Smite"] = "Mr. Smite",
	["Murkblood Twin"] = "Murkblood Twin",
	["Murkblood Twins"] = "Murkblood Twins",
	Murmur = "Murmur",
	["Murta Grimgut"] = "Murta Grimgut",
	Mushgog = "Mushgog",
	["Mutanus the Devourer"] = "Mutanus the Devourer",
	Nalorakk = "Nalorakk",
	Nazan = "Nazan",
	Nefarian = "Nefarian",
	["Nekrum Gutchewer"] = "Nekrum Gutchewer",
	["Nerub'enkan"] = "Nerub'enkan",
	["Nethermancer Sepethrea"] = "Nethermancer Sepethrea",
	Netherspite = "Netherspite",
	["Netherstrand Longbow"] = "Netherstrand Longbow",
	["Nexus-Prince Shaffar"] = "Nexus-Prince Shaffar",
	Nightbane = "Nightbane",
	["Noth the Plaguebringer"] = "Noth the Plaguebringer",
	["Novos the Summoner"] = "Novos the Summoner",
	Noxxion = "Noxxion",
	["Obsidian Sentinel"] = "Obsidian Sentinel",
	["Odo the Blindwatcher"] = "Odo the Blindwatcher",
	["Ogom the Wretched"] = "Ogom the Wretched",
	["Ok'thor the Breaker"] = "Ok'thor the Breaker",
	["Old Serra'kis"] = "Old Serra'kis",
	["Olm the Summoner"] = "Olm the Summoner",
	["Omor the Unscarred"] = "Omor the Unscarred",
	Onyxia = "Onyxia",
	["Ormorok the Tree-Shaper"] = "Ormorok the Tree-Shaper",
	["Oro Eyegouge"] = "Oro Eyegouge",
	["Ossirian the Unscarred"] = "Ossirian the Unscarred",
	Ouro = "Ouro",
	["Overlord Ramtusk"] = "Overlord Ramtusk",
	["Overlord Wyrmthalak"] = "Overlord Wyrmthalak",
	["Overmaster Pyron"] = "Overmaster Pyron",
	["Overseer Tidewrath"] = "Overseer Tidewrath",
	Pandemonius = "Pandemonius",
	["Panzor the Invincible"] = "Panzor the Invincible",
	Patchwerk = "Patchwerk",
	["Pathaleon the Calculator"] = "Pathaleon the Calculator",
	Phalanx = "Phalanx",
	["Phaseshift Bulwark"] = "Phaseshift Bulwark",
	Pimgib = "Pimgib",
	["Plaguemaw the Rotting"] = "Plaguemaw the Rotting",
	["Plugger Spazzring"] = "Plugger Spazzring",
	["Postmaster Malown"] = "Postmaster Malown",
	["Priestess Delrissa"] = "Priestess Delrissa",
	["Prince Keleseth"] = "Prince Keleseth",
	["Prince Malchezaar"] = "Prince Malchezaar",
	["Prince Skaldrenox"] = "Prince Skaldrenox",
	["Prince Taldaram"] = "Prince Taldaram",
	["Prince Tortheldrin"] = "Prince Tortheldrin",
	["Princess Huhuran"] = "Princess Huhuran",
	["Princess Moira Bronzebeard"] = "Princess Moira Bronzebeard",
	["Princess Tempestria"] = "Princess Tempestria",
	["Princess Theradras"] = "Princess Theradras",
	["Princess Yauj"] = "Princess Yauj",
	["Pure Spawn of Hydross"] = "Pure Spawn of Hydross",
	Pusillin = "Pusillin",
	["Pyroguard Emberseer"] = "Pyroguard Emberseer",
	["Pyromancer Loregrain"] = "Pyromancer Loregrain",
	Quagmirran = "Quagmirran",
	["Quartermaster Zigris"] = "Quartermaster Zigris",
	["Rage Winterchill"] = "Rage Winterchill",
	Ragglesnout = "Ragglesnout",
	Ragnaros = "Ragnaros",
	["Ramstein the Gorger"] = "Ramstein the Gorger",
	["Ras Frostwhisper"] = "Ras Frostwhisper",
	Rattlegore = "Rattlegore",
	["Razorclaw the Butcher"] = "Razorclaw the Butcher",
	["Razorgore the Untamed"] = "Razorgore the Untamed",
	Razorlash = "Razorlash",
	["Reliquary of Souls"] = "Reliquary of Souls",
	Renataki = "Renataki",
	["Restless Skeleton"] = "Restless Skeleton",
	Revelosh = "Revelosh",
	["Rhahk'Zor"] = "Rhahk'Zor",
	["Ribbly Screwspigot"] = "Ribbly Screwspigot",
	Roar = "Roar",
	["Rokad the Ravager"] = "Rokad the Ravager",
	["Rokdar the Sundered Lord"] = "Rokdar the Sundered Lord",
	["Rokmar the Crackler"] = "Rokmar the Crackler",
	Romulo = "Romulo",
	["Romulo & Julianne"] = "Romulo & Julianne",
	Rotgrip = "Rotgrip",
	Ruuzlu = "Ruuzlu",
	["Salramm the Fleshcrafter"] = "Salramm the Fleshcrafter",
	["Sandarr Dunereaver"] = "Sandarr Dunereaver",
	["Sandfury Executioner"] = "Sandfury Executioner",
	Sapphiron = "Sapphiron",
	Sartharion = "Sartharion",
	["Sathrovarr the Corruptor"] = "Sathrovarr the Corruptor",
	["Scarlet Commander Mograine"] = "Scarlet Commander Mograine",
	["Seeth'rel"] = "Seeth'rel",
	["Selin Fireheart"] = "Selin Fireheart",
	["Sergeant Bly"] = "Sergeant Bly",
	["Shade of Akama"] = "Shade of Akama",
	["Shade of Aran"] = "Shade of Aran",
	["Shade of Eranikus"] = "Shade of Eranikus",
	["Shadikith the Glider"] = "Shadikith the Glider",
	["Shadow Hunter Vosh'gajin"] = "Shadow Hunter Vosh'gajin",
	["Shadow of Leotheras"] = "Shadow of Leotheras",
	["Shadowpriest Sezz'ziz"] = "Shadowpriest Sezz'ziz",
	Shadron = "Shadron",
	Shazzrah = "Shazzrah",
	["Shirrak the Dead Watcher"] = "Shirrak the Dead Watcher",
	["Sir Zeliek"] = "Sir Zeliek",
	["Sjonnir The Ironshaper"] = "Sjonnir The Ironshaper",
	["Skadi the Ruthless"] = "Skadi the Ruthless",
	["Skarr the Unbreakable"] = "Skarr the Unbreakable",
	["Skarvald the Constructor"] = "Skarvald the Constructor",
	["Skra'gath"] = "Skra'gath",
	Skul = "Skul",
	Skum = "Skum",
	["Slad'ran"] = "Slad'ran",
	Sneed = "Sneed",
	["Sneed's Shredder"] = "Sneed's Shredder",
	["Solakar Flamewreath"] = "Solakar Flamewreath",
	["Solarium Agent"] = "Solarium Agent",
	["Solarium Priest"] = "Solarium Priest",
	["Spirestone Battle Lord"] = "Spirestone Battle Lord",
	["Spirestone Butcher"] = "Spirestone Butcher",
	["Spirestone Lord Magus"] = "Spirestone Lord Magus",
	["Staff of Disintegration"] = "Staff of Disintegration",
	Stalagg = "Stalagg",
	["Stomper Kreeg"] = "Stomper Kreeg",
	Stonespine = "Stonespine",
	Strawman = "Strawman",
	["Sulfuron Harbinger"] = "Sulfuron Harbinger",
	Supremus = "Supremus",
	["Svala Sorrowgrave"] = "Svala Sorrowgrave",
	["Swamplord Musel'ek"] = "Swamplord Musel'ek",
	Taerar = "Taerar",
	["Tainted Spawn of Hydross"] = "Tainted Spawn of Hydross",
	["Talon King Ikiss"] = "Talon King Ikiss",
	["Taragaman the Hungerer"] = "Taragaman the Hungerer",
	["Targorr the Dread"] = "Targorr the Dread",
	Tavarok = "Tavarok",
	Techbot = "Techbot",
	Temporus = "Temporus",
	["Tendris Warpwood"] = "Tendris Warpwood",
	Tenebron = "Tenebron",
	["Terestian Illhoof"] = "Terestian Illhoof",
	["Teron Gorefiend"] = "Teron Gorefiend",
	Thaddius = "Thaddius",
	["Thaladred the Darkener"] = "Thaladred the Darkener",
	["Thane Korth'azz"] = "Thane Korth'azz",
	["The Beast"] = "The Beast",
	["The Big Bad Wolf"] = "The Big Bad Wolf",
	["The Black Stalker"] = "The Black Stalker",
	["The Blue Brothers"] = "The Blue Brothers",
	["The Bug Family"] = "The Bug Family",
	["The Crone"] = "The Crone",
	["The Curator"] = "The Curator",
	["The Eredar Twins"] = "The Eredar Twins",
	["The Four Horsemen"] = "The Four Horsemen",
	["The Illidari Council"] = "The Illidari Council",
	["The Lurker Below"] = "The Lurker Below",
	["The Maker"] = "The Maker",
	["The Prophet Skeram"] = "The Prophet Skeram",
	["The Prophet Tharon'ja"] = "The Prophet Tharon'ja",
	["The Ravenian"] = "The Ravenian",
	["The Razza"] = "The Razza",
	["The Seven Dwarves"] = "The Seven Dwarves",
	["The Tribunal of Ages"] = "The Tribunal of Ages",
	["The Twin Emperors"] = "The Twin Emperors",
	["The Unforgiven"] = "The Unforgiven",
	["The Windreaver"] = "The Windreaver",
	["Theka the Martyr"] = "Theka the Martyr",
	["Thorngrin the Tender"] = "Thorngrin the Tender",
	["Tidewalker Lurker"] = "Tidewalker Lurker",
	["Timmy the Cruel"] = "Timmy the Cruel",
	Tinhead = "Tinhead",
	["Tinkerer Gizlock"] = "Tinkerer Gizlock",
	Tito = "Tito",
	["Trigore the Lasher"] = "Trigore the Lasher",
	Trollgore = "Trollgore",
	["Tsu'zee"] = "Tsu'zee",
	["Tuten'kash"] = "Tuten'kash",
	["Twilight Lord Kelris"] = "Twilight Lord Kelris",
	["Urok Doomhowl"] = "Urok Doomhowl",
	["Vaelastrasz the Corrupt"] = "Vaelastrasz the Corrupt",
	["Varos Cloudstrider"] = "Varos Cloudstrider",
	Vazruden = "Vazruden",
	["Vazruden the Herald"] = "Vazruden the Herald",
	Vectus = "Vectus",
	Vem = "Vem",
	Veng = "Veng",
	["Veras Darkshadow"] = "Veras Darkshadow",
	["Verdan the Everliving"] = "Verdan the Everliving",
	Verek = "Verek",
	Vesperon = "Vesperon",
	Vexallus = "Vexallus",
	["Veyzhak the Cannibal"] = "Veyzhak the Cannibal",
	["Vile'rel"] = "Vile'rel",
	Viscidus = "Viscidus",
	["Viscous Fallout"] = "Viscous Fallout",
	["Void Reaver"] = "Void Reaver",
	Volkhan = "Volkhan",
	["War Master Voone"] = "War Master Voone",
	["Warbringer O'mrogg"] = "Warbringer O'mrogg",
	["Warchief Blackhand Piece"] = "Warchief Blackhand Piece",
	["Warchief Kargath Bladefist"] = "Warchief Kargath Bladefist",
	["Warchief Rend Blackhand"] = "Warchief Rend Blackhand",
	["Warden Mellichar"] = "Warden Mellichar",
	["Warder Stilgiss"] = "Warder Stilgiss",
	["Warlord Kalithresh"] = "Warlord Kalithresh",
	["Warmaul Champion"] = "Warmaul Champion",
	["Warp Slicer"] = "Warp Slicer",
	["Warp Splinter"] = "Warp Splinter",
	["Watchkeeper Gargolmar"] = "Watchkeeper Gargolmar",
	Weaver = "Weaver",
	["Witch Doctor Zum'rah"] = "Witch Doctor Zum'rah",
	["Wolf Master Nandos"] = "Wolf Master Nandos",
	["Wrath-Scryer Soccothrates"] = "Wrath-Scryer Soccothrates",
	Wushoolay = "Wushoolay",
	Xevozz = "Xevozz",
	Ysondre = "Ysondre",
	Zekkis = "Zekkis",
	["Zelemar the Wrathful"] = "Zelemar the Wrathful",
	["Zereketh the Unbound"] = "Zereketh the Unbound",
	Zerillis = "Zerillis",
	["Zevrim Thornhoof"] = "Zevrim Thornhoof",
	Zolo = "Zolo",
	["Zul'Farrak Dead Hero"] = "Zul'Farrak Dead Hero",
	["Zul'jin"] = "Zul'jin",
	["Zul'Lor"] = "Zul'Lor",
	["Zuramat the Obliterator"] = "Zuramat the Obliterator",
}

--[===[@debug@
}
--@end-debug@]===]

if GAME_LOCALE == "enUS" then
	lib:SetCurrentTranslations(true)
elseif GAME_LOCALE == "deDE" then
	lib:SetCurrentTranslations
--[===[@debug@
	{
--@end-debug@]===]
	{
	Aeonus = "Aeonus",
	["Agathelos the Raging"] = "Agathelos der Tobende",
	Ahune = "Ahune",
	["Akil'zon"] = "Akil'zon",
	["Aku'mai"] = "Aku'mai",
	["Al'ar"] = "Al'ar",
	["Alzzin the Wildshaper"] = "Alzzin der Wildformer",
	Amanitar = "Amanitar",
	["Ambassador Flamelash"] = "Botschafter Flammenschlag",
	["Ambassador Hellmaw"] = "Botschafter Höllenschlund",
	["Amnennar the Coldbringer"] = "Amnennar der Kältebringer",
	["Ancient Stone Keeper"] = "Uralter Steinbewahrer",
	Anetheron = "Anetheron",
	["Anger'rel"] = "Anger'rel",
	Anomalus = "Anomalus",
	["Antu'sul"] = "Antu'sul",
	["Anub'arak"] = "Anub'arak",
	["Anub'Rekhan"] = "Anub'Rekhan",
	["Anub'shiah"] = "Anub'shiah",
	["Anubisath Defender"] = "Verteidiger des Anubisath",
	["Anubisath Guardian"] = "Beschützer des Anubisath",
	Anzu = "Anzu",
	["Arcane Watchman"] = "Arkanwachmann",
	["Arcanist Doan"] = "Arkanist Doan",
	Archaedas = "Archaedas",
	["Archavon the Stone Watcher"] = "Archavon der Steinwächter",
	Archimonde = "Archimonde",
	["Archivist Galford"] = "Archivar Galford",
	["Archmage Arugal"] = "Erzmagier Arugal",
	["Arugal's Voidwalker"] = "Arugals Leerwandler",
	["Atal'alarion"] = "Atal'alarion",
	["Attumen the Huntsman"] = "Attumen der Jäger",
	Avalanchion = "Avalanchion",
	["Avatar of Hakkar"] = "Avatar von Hakkar",
	["Ayamiss the Hunter"] = "Ayamiss der Jäger",
	Azgalor = "Azgalor",
	["Azshir the Sleepless"] = "Azshir der Schlaflose",
	Azuregos = "Azuregos",
	["Bael'Gar"] = "Bael'Gar",
	Baelog = "Baelog",
	Balnazzar = "Balnazzar",
	["Bannok Grimaxe"] = "Bannok Grimmaxt",
	["Baron Aquanis"] = "Baron Aquanis",
	["Baron Charr"] = "Baron Glutarr",
	["Baron Geddon"] = "Baron Geddon",
	["Baron Kazum"] = "Baron Kazum",
	["Baron Rivendare"] = "Baron Totenschwur",
	["Baron Silverlaine"] = "Baron Silberlein",
	["Baroness Anastari"] = "Baroness Anastari",
	["Battleguard Sartura"] = "Schlachtwache Sartura",
	["Bazil Thredd"] = "Bazil Thredd",
	Bazzalan = "Bazzalan",
	["Black Guard Swordsmith"] = "Schwertschmied der schwarzen Wache",
	["Blackheart the Inciter"] = "Schwarzherz der Hetzer",
	["Blind Hunter"] = "Blinder Jäger",
	["Blindeye the Seer"] = "Blindauge der Seher",
	["Blood Guard Porung"] = "Blutwache Porung",
	["Blood Steward of Kirtonos"] = "Blutdiener von Kirtonos",
	["Bloodlord Mandokir"] = "Blutfürst Mandokir",
	["Bloodmage Thalnos"] = "Blutmagier Thalnos",
	Boahn = "Boahn",
	["Brainwashed Noble"] = "Manipulierter Adliger",
	Broggok = "Broggok",
	Brokentoe = "Schmetterzehe",
	["Broodlord Lashlayer"] = "Brutwächter Dreschbringer",
	["Bruegal Ironknuckle"] = "Bruegal Eisenfaust",
	Brutallus = "Brutallus",
	["Burning Felguard"] = "Brennende Teufelswache",
	["Buru the Gorger"] = "Buru der Verschlinger",
	["C'Thun"] = "C'Thun",
	["Cache of the Firelord"] = "Truhe des Feuerlords",
	["Cannon Master Willey"] = "Kanonenmeister Willey",
	["Captain Greenskin"] = "Kapitän Grünhaut",
	["Captain Kromcrush"] = "Hauptmann Krombruch",
	["Captain Skarloc"] = "Kapitän Skarloc",
	["Celebras the Cursed"] = "Celebras der Verfluchte",
	["Charlga Razorflank"] = "Charlga Klingenflanke",
	["Chess Event"] = "Chess Event",
	["Chest of The Seven"] = "Truhe der Sieben",
	["Chief Ukorz Sandscalp"] = "Häuptling Ukorz Sandwüter",
	["Cho'Rush the Observer"] = "Cho'Rush der Beobachter",
	Chromaggus = "Chromaggus",
	["Chrono Lord Deja"] = "Chronolord Deja",
	["Chrono-Lord Epoch"] = "Chronolord Epoch",
	Claw = "Klaue",
	["Coilfang Elite"] = "Elitesoldat des Echsenkessels",
	["Coilfang Strider"] = "Schreiter des Echsenkessels",
	["Commander Kolurg"] = "Kommandant Kolurg",
	["Commander Sarannis"] = "Kommandant Sarannis",
	["Commander Springvale"] = "Kommandant Springvale",
	["Commander Stoutbeard"] = "Kommandant Starkbart",
	["Constructor & Controller"] = "Konstrukteur & Kontrolleur",
	Cookie = "Krümel",
	["Cosmic Infuser"] = "Kosmische Macht",
	["Crimson Hammersmith"] = "Purpurroter Hammerschmied",
	["Crowd Pummeler 9-60"] = "Meuteverprügler 9-60",
	["Crystal Fang"] = "Kristallfangzahn",
	Cyanigosa = "Cyanigosa",
	["Dalliah the Doomsayer"] = "Dalliah die Verdammnisverkünderin",
	["Dalronn the Controller"] = "Dalronn der Kontrolleur",
	["Dark Iron Ambassador"] = "Botschafter der Dunkeleisenzwerge",
	["Darkmaster Gandling"] = "Dunkelmeister Gandling",
	["Darkweaver Syth"] = "Dunkelwirker Syth",
	["Death Knight Darkreaver"] = "Todesritter Schattensichel",
	["Death knight Understudy"] = "Reservist der Todesritter",
	["Death Speaker Jargba"] = "Todessprecher Jargba",
	["Deathsworn Captain"] = "Todeshöriger Captain",
	Devastation = "Verwüstung",
	["Deviate Faerie Dragon"] = "Deviatfeendrache",
	["Dextren Ward"] = "Dextren Ward",
	["Digmaster Shovelphlange"] = "Grubenmeister Schaufelphlansch",
	["Doctor Theolen Krastinov"] = "Doktor Theolen Krastinov",
	["Doom Lord Kazzak"] = "Verdammnislord Kazzak",
	["Doom'rel"] = "Un'rel",
	Doomwalker = "Verdammniswandler",
	["Dope'rel"] = "Trott'rel",
	Dorothee = "Dorothee",
	["Drakkari Colossus"] = "Drakkari Koloss",
	["Drakos the Interrogator"] = "Drakos der Fragensteller",
	Dreamscythe = "Traumsense",
	["Dust Covered Chest"] = "Staub Bedeckter Kasten",
	Dustwraith = "Karaburan",
	["Earthcaller Halmgar"] = "Erdenrufer Halmgar",
	Ebonroc = "Schattenschwinge",
	["Eck the Ferocious"] = "Eck der Grausame",
	["Edwin VanCleef"] = "Edwin van Cleef",
	["Elder Nadox"] = "Urahne Nadox",
	["Electrocutioner 6000"] = "Elektrokutor 6000",
	Emeriss = "Smariss",
	["Emperor Dagran Thaurissan"] = "Imperator Dagran Thaurissan",
	["Emperor Vek'lor"] = "Imperator Vek'lor",
	["Emperor Vek'nilash"] = "Imperator Vek'nilash",
	Entropius = "Entropius",
	["Epoch Hunter"] = "Epochenjäger",
	Erekem = "Erekem",
	["Essence of Anger"] = "Essenz des Zorns",
	["Essence of Desire"] = "Essenz der Begierde",
	["Essence of Suffering"] = "Essenz des Leidens",
	Eviscerator = "Ausweider",
	["Exarch Maladaar"] = "Exarch Maladaar",
	["Eye of C'Thun"] = "Auge von C'Thun",
	["Fallen Champion"] = "Gestürzter Held",
	["Fankriss the Unyielding"] = "Fankriss der Unnachgiebige",
	["Fathom-Lord Karathress"] = "Tiefenlord Karathress",
	Felmyst = "Teufelsruch",
	["Fenrus the Devourer"] = "Fenrus der Verschlinger",
	Feugen = "Feugen",
	["Fineous Darkvire"] = "Fineous Dunkelader",
	Firemaw = "Feuerschwinge",
	Flamegor = "Flammenmaul",
	["Foreman Thistlenettle"] = "Großknecht Distelklette",
	["Four Horsemen Chest"] = "Die Vier Reiter Kiste",
	["Fras Siabi"] = "Fras Siabi",
	["Gahz'ranka"] = "Gahz'ranka",
	["Gahz'rilla"] = "Gahz'rilla",
	["Gal'darah"] = "Gal'darah",
	["Galgann Firehammer"] = "Galgann Feuerhammer",
	Garr = "Garr",
	Gasher = "Schlitzer",
	["Gatewatcher Gyro-Kill"] = "Torwächter Gyrotot",
	["Gatewatcher Iron-Hand"] = "Torwächter Eisenhand",
	["Gathios the Shatterer"] = "Gathios der Zerschmetterer",
	Gehennas = "Gehennas",
	Gelihast = "Gelihast",
	Gelk = "Gelk",
	["General Angerforge"] = "General Zornesschmied",
	["General Bjarngrim"] = "General Bjarngrim",
	["General Drakkisath"] = "General Drakkisath",
	["General Rajaxx"] = "General Rajaxx",
	["Ghamoo-ra"] = "Ghamoo-ra",
	["Ghaz'an"] = "Ghaz'an",
	["Ghok Bashguud"] = "Ghok Haudrauf",
	Gilnid = "Gilnid",
	["Gizrul the Slavener"] = "Gizrul der Geifernde",
	["Gloom'rel"] = "Dunk'rel",
	Gluth = "Gluth",
	Glutton = "Nimmersatt",
	["Golem Lord Argelmach"] = "Golemlord Argelmach",
	["Golemagg the Incinerator"] = "Golemagg der Verbrenner",
	["Goraluk Anvilcrack"] = "Goraluk Hammerbruch",
	["Gorosh the Dervish"] = "Gorosh der Derwisch",
	["Gortok Palehoof"] = "Gortok Bleichhuf",
	["Gothik the Harvester"] = "Gothik der Ernter",
	["Grand Astromancer Capernian"] = "Großastronom Capernian",
	["Grand Magus Telestra"] = "Großmagistrix Telestra",
	["Grand Warlock Alythess"] = "Großhexenmeisterin Alythess",
	["Grand Warlock Nethekurse"] = "Großhexenmeister Nethekurse",
	["Grand Widow Faerlina"] = "Großwitwe Faerlina",
	["Grandmaster Vorpil"] = "Großmeister Vorpil",
	Grandmother = "Großmutter",
	["Grethok the Controller"] = "Grethok der Aufseher",
	["Gri'lek"] = "Gri'lek",
	Grimlok = "Grimlok",
	Grizzle = "Grizzle",
	Grobbulus = "Grobbulus",
	Grubbis = "Grubbis",
	["Gruul the Dragonkiller"] = "Gruul der Drachenschlächter",
	["Guard Fengus"] = "Wache Fengus",
	["Guard Mol'dar"] = "Wache Mol'dar",
	["Guard Slip'kik"] = "Wache Slip'kik",
	["Gurtogg Bloodboil"] = "Gurtogg Siedeblut",
	Gyth = "Gyth",
	Hadronox = "Hadronox",
	Hakkar = "Hakkar",
	Halazzi = "Halazzi",
	Halycon = "Halycon",
	Hamhock = "Hamhock",
	["Harbinger Skyriss"] = "Herold Horizontiss",
	["Hate'rel"] = "Hass'rel",
	["Hazza'rah"] = "Hazza'rah",
	Hazzas = "Hazzas",
	["Headless Horseman"] = "Der kopflose Reiter",
	["Hearthsinger Forresten"] = "Herdsinger Forresten",
	["Hedrum the Creeper"] = "Hedrum der Krabbler",
	["Heigan the Unclean"] = "Heigan der Unreine",
	["Hellfire Channeler"] = "Kanalisierer des Höllenfeuers",
	-- ["Henry Stern"] = "Henry Stern", -- Requires localization
	["Herald Volazj"] = "Verkünder Volazj",
	Herod = "Herod",
	["Hex Lord Malacrass"] = "Hexlord Malacrass",
	["High Astromancer Solarian"] = "Hochastromantin Solarian",
	["High Botanist Freywinn"] = "Hochbotaniker Freywinn",
	["High Inquisitor Fairbanks"] = "Hochinquisitor Fairbanks",
	["High Inquisitor Whitemane"] = "Hochinquisitor Weißsträhne",
	["High Interrogator Gerstahn"] = "Verhörmeisterin Gerstahn",
	["High King Maulgar"] = "Hochkönig Maulgar",
	["High Marshal Whirlaxis"] = "Hochmarschall Whirlaxis",
	["High Nethermancer Zerevor"] = "Hochnethermant Zerevor",
	["High Priest Thekal"] = "Hohepriester Thekal",
	["High Priest Venoxis"] = "Hohepriester Venoxis",
	["High Priestess Arlokk"] = "Hohepriesterin Arlokk",
	["High Priestess Jeklik"] = "Hohepriesterin Jeklik",
	["High Priestess Mar'li"] = "Hohepriesterin Mar'li",
	["High Priestess of Thaurissan"] = "\009Hohepriesterin von Thaurissan",
	["High Warlord Naj'entus"] = "Oberster Kriegsfürst Naj'entus",
	["Highlord Mograine"] = "Hochlord Mograine",
	["Highlord Omokk"] = "Hochlord Omokk",
	["Houndmaster Grebmar"] = "Hundemeister Grebmar",
	["Houndmaster Loksey"] = "Hundemeister Loksey",
	Hukku = "Hukku",
	Hungarfen = "Hungarfenn",
	["Hurley Blackbreath"] = "Hurley Pestatem",
	["Hyakiss the Lurker"] = "Hyakiss der Lauerer",
	["Hydromancer Thespia"] = "Wasserbeschwörerin Thespia",
	["Hydromancer Velratha"] = "Wasserbeschwörerin Velratha",
	Hydrospawn = "Hydrobrut",
	["Hydross the Unstable"] = "Hydross der Unstete",
	Ichoron = "Ichoron",
	["Illidan Stormrage"] = "Illidan Sturmgrimm",
	["Illidari Council"] = "Rat der Illidari",
	["Illyanna Ravenoak"] = "Illyanna Rabeneiche",
	["Immol'thar"] = "Immol'thar",
	["Infinite Corruptor"] = "Ewiger Verderber",
	["Infinity Blades"] = "Klinge der Unendlichkeit",
	["Ingvar the Plunderer"] = "Ingvar der Brandschatzer",
	["Instructor Malicia"] = "Instrukteurin Malicia",
	["Instructor Razuvious"] = "Instrukteur Razuvious",
	["Interrogator Vishas"] = "Befrager Vishas",
	Ionar = "Ionar",
	Ironaya = "Ironaya",
	Ironspine = "Eisenrücken",
	Isalien = "Isalien",
	Jade = "Jade",
	["Jammal'an the Prophet"] = "Jammal'an der Prophet",
	["Jan'alai"] = "Jan'alai",
	["Jandice Barov"] = "Jandice Barov",
	["Jed Runewatcher"] = "Jed Runenblick",
	["Jedoga Shadowseeker"] = "Jedoga Schattensucher",
	["Jergosh the Invoker"] = "Jergosh der Herbeirufer",
	["Jin'do the Hexxer"] = "Jin'do der Verhexer",
	Julianne = "Julianne",
	["Kael'thas Sunstrider"] = "Kael'thas Sonnenwanderer",
	Kalecgos = "Kalecgos",
	["Kam Deepfury"] = "Kam Tiefenzorn",
	["Kaz'rogal"] = "Kaz'rogal",
	["Kazkaz the Unholy"] = "Kazkaz der Unheilige",
	["Kel'Thuzad"] = "Kel'Thuzad",
	["Keli'dan the Breaker"] = "Keli'dan der Zerstörer",
	Keristrasza = "Keristrasza",
	["Kiggler the Crazed"] = "Kiggler the Crazed",
	["Kil'jaeden"] = "Kil'jaeden",
	["Kil'rek"] = "Kil'rek",
	["King Dred"] = "König Dred",
	["King Gordok"] = "König Gordok",
	["King Llane Piece"] = "König Llane",
	["King Ymiron"] = "König Ymiron",
	["Kirtonos the Herald"] = "Kirtonos der Herold",
	["Knot Thimblejack's Cache"] = "Knot Thimblejacks Truhe",
	Kolk = "Kolk",
	Kormok = "Kormok",
	Kresh = "Kresh",
	["Krik'thir the Gatewatcher"] = "Krik'thir der Torwächter",
	["Krosh Firehand"] = "Krosh Feuerhand",
	Krystallus = "Krystallus",
	Kurinnaxx = "Kurinnaxx",
	["Lady Anacondra"] = "Lady Anacondra",
	["Lady Blaumeux"] = "Lady Blaumeux",
	["Lady Illucia Barov"] = "Lady Illucia Barov",
	["Lady Malande"] = "Lady Malande",
	["Lady Sacrolash"] = "Lady Sacrolash",
	["Lady Sarevess"] = "Lady Sarevess",
	["Lady Vashj"] = "Lady Vashj",
	Laj = "Laj",
	Landslide = "Erdrutsch",
	Lavanthor = "Lavanthor",
	["Leotheras the Blind"] = "Leotheras der Blinde",
	Lethon = "Lethon",
	Lethtendris = "Lethtendris",
	["Ley-Guardian Eregos"] = "Leywächter Eregos",
	["Lieutenant Drake"] = "Leutnant Drach",
	["Lieutenant General Andorov"] = "Generallieutenant Andorov",
	Loatheb = "Loatheb",
	Loken = "Loken",
	["Lord Alexei Barov"] = "Lord Alexei Barov",
	["Lord Cobrahn"] = "Lord Kobrahn",
	["Lord Hel'nurath"] = "Lord Hel'nurath",
	["Lord Incendius"] = "Lord Incendius",
	["Lord Kazzak"] = "Lord Kazzak",
	["Lord Kri"] = "Lord Kri",
	["Lord Pythas"] = "Lord Pythas",
	["Lord Roccor"] = "Lord Roccor",
	["Lord Sanguinar"] = "Fürst Blutdurst",
	["Lord Serpentis"] = "Lord Serpentis",
	["Lord Skwol"] = "Lord Skwol",
	["Lord Valthalak"] = "Lord Valthalak",
	["Lord Victor Nefarius"] = "Lord Victor Nefarius",
	["Lord Vyletongue"] = "Lord Schlangenzunge",
	["Lorekeeper Polkelt"] = "Hüter des Wissens Polkelt",
	Loro = "Loro",
	Lucifron = "Lucifron",
	["M'uru"] = "M'uru",
	["Mad Magglish"] = "Zausel der Verrückte",
	Maexxna = "Maexxna",
	["Mage-Lord Urom"] = "Magierlord Urom",
	["Magister Kalendris"] = "Magister Kalendris",
	["Magistrate Barthilas"] = "Magistrat Barthilas",
	Magmadar = "Magmadar",
	Magmus = "Magmus",
	Magra = "Magra",
	Magtheridon = "Magtheridon",
	["Maiden of Grief"] = "Maid der Trauer",
	["Maiden of Virtue"] = "Tugendhafte Maid",
	["Majordomo Executus"] = "Majordomus Exekutus",
	["Mal'Ganis"] = "Mal'Ganis",
	Malacrass = "Malacrass",
	["Maleki the Pallid"] = "Maleki der Leichenblasse",
	Malygos = "Malygos",
	Maraudos = "Maraudos",
	["Marduk Blackpool"] = "Marduk Blackpool",
	["Marisa du'Paige"] = "Marisa du'Paige",
	["Master Engineer Telonicus"] = "Meisteringenieur Telonicus",
	["Maur Grimtotem"] = "Maur Grimmtotem",
	Meathook = "Meathook",
	["Mechano-Lord Capacitus"] = "Mechanolord Kapazitus",
	Medivh = "Medivh",
	["Mekgineer Steamrigger"] = "Robogenieur Dampfhammer",
	["Mekgineer Thermaplugg"] = "Robogenieur Thermadraht",
	["Mennu the Betrayer"] = "Mennu der Verräter",
	["Meshlok the Harvester"] = "Meshlok der Ernter",
	Midnight = "Mittnacht",
	Mijan = "Mijan",
	["Miner Johnson"] = "Minenarbeiter Johnson",
	Moam = "Moam",
	Mogor = "Mogor",
	Moorabi = "Moorabi",
	["Mor Grayhoof"] = "Mor Grauhuf",
	Moragg = "Moragg",
	["Mordresh Fire Eye"] = "Mordresh Feuerauge",
	Moroes = "Moroes",
	["Morogrim Tidewalker"] = "Morogrim Gezeitenwandler",
	Morphaz = "Morphaz",
	["Mother Shahraz"] = "Mutter Shahraz",
	["Mother Smolderweb"] = "Mutter Glimmernetz",
	["Mr. Smite"] = "Handlanger Pein",
	["Murkblood Twin"] = "Zwilling der Finsterblut",
	["Murkblood Twins"] = "Zwillinge der Finsterblut",
	Murmur = "Murmur",
	["Murta Grimgut"] = "Murta Bauchgrimm",
	Mushgog = "Mushgog",
	["Mutanus the Devourer"] = "Mutanus der Verschlinger",
	Nalorakk = "Nalorakk",
	Nazan = "Nazan",
	Nefarian = "Nefarian",
	["Nekrum Gutchewer"] = "Nekrum der Ausweider",
	["Nerub'enkan"] = "Nerub'enkan",
	["Nethermancer Sepethrea"] = "Nethermant Sepethrea",
	Netherspite = "Nethergroll",
	["Netherstrand Longbow"] = "Netherbespannter Langbogen",
	["Nexus-Prince Shaffar"] = "Nexusprinz Shaffar",
	Nightbane = "Schrecken der Nacht",
	["Noth the Plaguebringer"] = "Noth der Seuchenfürst",
	["Novos the Summoner"] = "Novos der Beschwörer",
	Noxxion = "Noxxion",
	["Obsidian Sentinel"] = "Obsidianschildwache",
	["Odo the Blindwatcher"] = "Odo der Blindseher",
	["Ogom the Wretched"] = "Ogom der Elende",
	["Ok'thor the Breaker"] = "Ok'thor der Zerstörer",
	["Old Serra'kis"] = "Old Serra'kis",
	["Olm the Summoner"] = "Olm der Beschwörer",
	["Omor the Unscarred"] = "Omor der Narbenlose",
	Onyxia = "Onyxia",
	["Ormorok the Tree-Shaper"] = "Ormorok der Baumformer",
	["Oro Eyegouge"] = "Oro Hohlauge",
	["Ossirian the Unscarred"] = "Ossirian der Narbenlose",
	Ouro = "Ouro",
	["Overlord Ramtusk"] = "Oberanführer Rammhauer",
	["Overlord Wyrmthalak"] = "Oberanführer Wyrmthalak",
	["Overmaster Pyron"] = "Übermeister Pyron",
	["Overseer Tidewrath"] = "Overseer Tidewrath",
	Pandemonius = "Pandemonius",
	["Panzor the Invincible"] = "Panzor der Unbesiegbare",
	Patchwerk = "Flickwerk",
	["Pathaleon the Calculator"] = "Pathaleon der Kalkulator",
	Phalanx = "Phalanx",
	["Phaseshift Bulwark"] = "Phasenverschobenes Bollwerk",
	Pimgib = "Pimgib",
	["Plaguemaw the Rotting"] = "Seuchenschlund der Faulende",
	["Plugger Spazzring"] = "Stöpsel Zapfring",
	["Postmaster Malown"] = "Postmeister Malown",
	["Priestess Delrissa"] = "Priesterin Delrissa",
	["Prince Keleseth"] = "Prinz Keleseth",
	["Prince Malchezaar"] = "Prinz Malchezaar",
	["Prince Skaldrenox"] = "Prince Skaldrenox",
	["Prince Taldaram"] = "Prinz Taldaram",
	["Prince Tortheldrin"] = "Prinz Tortheldrin",
	["Princess Huhuran"] = "Prinzessin Huhuran",
	["Princess Moira Bronzebeard"] = "Prinzessin Moira Bronzebeard",
	["Princess Tempestria"] = "Prinzessin Tempestria",
	["Princess Theradras"] = "Prinzessin Theradras",
	["Princess Yauj"] = "Prinzessin Yauj",
	["Pure Spawn of Hydross"] = "Gereinigter Nachkomme Hydross'",
	Pusillin = "Pusillin",
	["Pyroguard Emberseer"] = "Feuerwache Glutseher",
	["Pyromancer Loregrain"] = "Pyromant Weisenkorn",
	Quagmirran = "Quagmirran",
	["Quartermaster Zigris"] = "Rüstmeister Zigris",
	["Rage Winterchill"] = "Furor Winterfrost",
	Ragglesnout = "Struppmähne",
	Ragnaros = "Ragnaros",
	["Ramstein the Gorger"] = "Ramstein der Verschlinger",
	["Ras Frostwhisper"] = "Ras Frostraunen",
	Rattlegore = "Blutrippe",
	["Razorclaw the Butcher"] = "Klingenklaue der Metzger",
	["Razorgore the Untamed"] = "Razorgore der Ungezähmte",
	Razorlash = "Schlingwurzler",
	["Reliquary of Souls"] = "Reliquium der Seelen",
	Renataki = "Renataki",
	["Restless Skeleton"] = "Ruheloses Skelett",
	Revelosh = "Revelosh",
	["Rhahk'Zor"] = "Rhahk'Zor",
	["Ribbly Screwspigot"] = "Ribbly Schraubstutz",
	Roar = "Brüller",
	["Rokad the Ravager"] = "Rokad der Verheerer",
	["Rokdar the Sundered Lord"] = "Rokdar der Zerklüftete",
	["Rokmar the Crackler"] = "Rokmar der Zerquetscher",
	Romulo = "Romulo",
	["Romulo & Julianne"] = "Romulo & Julianne",
	Rotgrip = "Faulschnapper",
	Ruuzlu = "Ruuzlu",
	["Salramm the Fleshcrafter"] = "Salramm der Fleischhandwerker",
	["Sandarr Dunereaver"] = "Sandarr der Wüstenräuber",
	["Sandfury Executioner"] = "Henker der Sandwüter",
	Sapphiron = "Saphiron",
	Sartharion = "Sartharion",
	["Sathrovarr the Corruptor"] = "Sathrovarr der Verderber",
	["Scarlet Commander Mograine"] = "Scharlachroter Kommandant Mograine",
	["Seeth'rel"] = "Wut'rel",
	["Selin Fireheart"] = "Selin Feuerherz",
	["Sergeant Bly"] = "Unteroffizier Bly",
	["Shade of Akama"] = "Akamas Schemen",
	["Shade of Aran"] = "Arans Schemen",
	["Shade of Eranikus"] = "Eranikus' Schemen",
	["Shadikith the Glider"] = "Shadikith der Segler",
	["Shadow Hunter Vosh'gajin"] = "Schattenjägerin Vosh'gajin",
	["Shadow of Leotheras"] = "Schatten von Leotheras",
	["Shadowpriest Sezz'ziz"] = "Schattenpriester Sezz'ziz",
	Shadron = "Shadron",
	Shazzrah = "Shazzrah",
	["Shirrak the Dead Watcher"] = "Shirrak der Totenwächter",
	["Sir Zeliek"] = "Sire Zeliek",
	["Sjonnir The Ironshaper"] = "Sjonnir der Eisenformer",
	["Skadi the Ruthless"] = "Skadi der Skrupellose",
	["Skarr the Unbreakable"] = "Skarr der Unbezwingbare",
	["Skarvald the Constructor"] = "Skarvald der Konstrukteur",
	["Skra'gath"] = "Skra'gath",
	Skul = "Skul",
	Skum = "Skum",
	["Slad'ran"] = "Slad'ran",
	Sneed = "Sneed",
	["Sneed's Shredder"] = "Sneeds Schredder",
	["Solakar Flamewreath"] = "Solakar Feuerkrone",
	["Solarium Agent"] = "Solarian Agent",
	["Solarium Priest"] = "Solarian Priester",
	["Spirestone Battle Lord"] = "Kampflord der Felsspitzoger",
	["Spirestone Butcher"] = "Metzger der Felsspitzoger",
	["Spirestone Lord Magus"] = "Maguslord der Felsspitzoger",
	["Staff of Disintegration"] = "Stab der Auflösung",
	Stalagg = "Stalagg",
	["Stomper Kreeg"] = "Stampfer Kreeg",
	Stonespine = "Steinbuckel",
	Strawman = "Strohmann",
	["Sulfuron Harbinger"] = "Sulfuronherold",
	Supremus = "Supremus",
	["Svala Sorrowgrave"] = "Svala Grabesleid",
	["Swamplord Musel'ek"] = "Sumpffürst Musel'ek",
	Taerar = "Taerar",
	["Tainted Spawn of Hydross"] = "Besudelter Nachkomme Hydross'",
	["Talon King Ikiss"] = "Klauenkönig Ikiss",
	["Taragaman the Hungerer"] = "Taragaman der Hungerleider",
	["Targorr the Dread"] = "Targorr der Schreckliche",
	Tavarok = "Tavarok",
	Techbot = "Techbot",
	Temporus = "Temporus",
	["Tendris Warpwood"] = "Tendris Wucherborke",
	Tenebron = "Tenebron",
	["Terestian Illhoof"] = "Terestian Siechhuf",
	["Teron Gorefiend"] = "Teron Blutschatten",
	Thaddius = "Thaddius",
	["Thaladred the Darkener"] = "Thaladred der Verfinsterer",
	["Thane Korth'azz"] = "Thane Korth'azz",
	["The Beast"] = "Die Bestie",
	["The Big Bad Wolf"] = "Der große böse Wolf",
	["The Black Stalker"] = "Die Schattenmutter",
	["The Blue Brothers"] = "Die Blaumänner",
	["The Bug Family"] = "Die Käferfamilie",
	["The Crone"] = "Die böse Hexe",
	["The Curator"] = "Der Kurator",
	["The Eredar Twins"] = "Die Eredar Zwillinge",
	["The Four Horsemen"] = "Die Vier Reiter",
	["The Illidari Council"] = "Rat der Illidari",
	["The Lurker Below"] = "Das Grauen aus der Tiefe",
	["The Maker"] = "Der Schöpfer",
	["The Prophet Skeram"] = "Der Prophet Skeram",
	["The Prophet Tharon'ja"] = "Der Prophet Tharon'ja",
	["The Ravenian"] = "Der Ravenier",
	["The Razza"] = "Der Razza",
	["The Seven Dwarves"] = "Die Sieben Zwerge",
	["The Tribunal of Ages"] = "Das Tribunal der Zeitalter",
	["The Twin Emperors"] = "Die Zwillings-Imperatoren",
	["The Unforgiven"] = "Der Unverziehene",
	["The Windreaver"] = "Der Windhäscher",
	["Theka the Martyr"] = "Theka der Märtyrer",
	["Thorngrin the Tender"] = "Dorngrin der Hüter",
	["Tidewalker Lurker"] = "Lauerer der Gezeitenwandler",
	["Timmy the Cruel"] = "Timmy der Grausame",
	Tinhead = "Blechkopf",
	["Tinkerer Gizlock"] = "Tüftler Gizlock",
	Tito = "Tito",
	["Trigore the Lasher"] = "Trigore der Peitscher",
	Trollgore = "Trollgrind",
	["Tsu'zee"] = "Tsu'zee",
	["Tuten'kash"] = "Tuten'kash",
	["Twilight Lord Kelris"] = "Lord des Schattenhammers Kelris",
	["Urok Doomhowl"] = "Urok Schreckensbote",
	["Vaelastrasz the Corrupt"] = "Vaelastrasz der Verdorbene",
	["Varos Cloudstrider"] = "Varos Wolkenschreiter",
	Vazruden = "Vazruden",
	["Vazruden the Herald"] = "Vazruden der Herold",
	Vectus = "Vectus",
	Vem = "Vem",
	Veng = "Veng",
	["Veras Darkshadow"] = "Veras Schwarzschatten",
	["Verdan the Everliving"] = "Verdan der Ewiglebende",
	Verek = "Verek",
	Vesperon = "Vesperon",
	Vexallus = "Vexallus",
	["Veyzhak the Cannibal"] = "Veyzhack der Kannibale",
	["Vile'rel"] = "Bös'rel",
	Viscidus = "Viscidus",
	["Viscous Fallout"] = "Verflüssigte Ablagerung",
	["Void Reaver"] = "Leerhäscher",
	Volkhan = "Volkhan",
	["War Master Voone"] = "Kriegsmeister Voone",
	["Warbringer O'mrogg"] = "Kriegshetzer O'mrogg",
	["Warchief Blackhand Piece"] = "Kriegshäuptling Schwarzfaust",
	["Warchief Kargath Bladefist"] = "Kriegshäuptling Kargath Messerfaust",
	["Warchief Rend Blackhand"] = "Kriegshäuptling Rend Schwarzfaust",
	["Warden Mellichar"] = "Aufseher Mellichar",
	["Warder Stilgiss"] = "\009Wärter Stilgiss",
	["Warlord Kalithresh"] = "Kriegsherr Kalithresh",
	["Warmaul Champion"] = "Champion der Totschläger",
	["Warp Slicer"] = "Warpschnitter",
	["Warp Splinter"] = "Warpzweig",
	["Watchkeeper Gargolmar"] = "Wachhabender Gargolmar",
	Weaver = "Wirker",
	["Witch Doctor Zum'rah"] = "Hexendoktor Zum'rah",
	["Wolf Master Nandos"] = "Wolfmeister Nados",
	["Wrath-Scryer Soccothrates"] = "Zornseher Soccothrates",
	Wushoolay = "Wushoolay",
	Xevozz = "Xevozz",
	Ysondre = "Ysondre",
	Zekkis = "Zekkis",
	-- ["Zelemar the Wrathful"] = "Zelemar the Wrathful", -- Requires localization
	["Zereketh the Unbound"] = "Zereketh der Unabhängige",
	Zerillis = "Zerillis",
	["Zevrim Thornhoof"] = "Zevrim Dornhuf",
	Zolo = "Zolo",
	["Zul'Farrak Dead Hero"] = "Untoter Held aus Zul'Farrak",
	["Zul'jin"] = "Zul'jin",
	["Zul'Lor"] = "Zul'Lor",
	["Zuramat the Obliterator"] = "Zuramat der Auslöscher",
}

--[===[@debug@
	}
--@end-debug@]===]
elseif GAME_LOCALE == "frFR" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "zhCN" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "zhTW" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "koKR" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "esMX" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "esES" then
	lib:SetCurrentTranslations {
	}
elseif GAME_LOCALE == "ruRU" then
	lib:SetCurrentTranslations {
	}
else
	error(("%s: Locale %q not supported"):format(MAJOR_VERSION, GAME_LOCALE))
end
